Capability taxonomy and capability-set types.
A Capability is a typed wallet operation a toolset may request access to.
A CapabilitySet is the de-duplicated set of capabilities parsed from the
stellar-agent-capabilities metadata key.
Structs
- Capability
Set - The de-duplicated set of capabilities declared by a toolset.
Enums
- Capability
- A wallet capability that a toolset may declare in its manifest.